==> huaweicloudsdkosm-3.0.54-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/list_unread_new_instant_messages_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUnreadNewInstantMessagesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'imunread': 'list[ImUnreadV2]'
    }

    attribute_map = {
        'imunread': 'imunread'
    }

    def __init__(self, imunread=None):
        """ListUnreadNewInstantMessagesResponse - a model defined in huaweicloud sdk"""
        
        super(ListUnreadNewInstantMessagesResponse, self).__init__()

        self._imunread = None
        self.discriminator = None

        if imunread is not None:
            self.imunread = imunread

    @property
    def imunread(self):
        """Gets the imunread of this ListUnreadNewInstantMessagesResponse.

        未读消息列表

        :return: The imunread of this ListUnreadNewInstantMessagesResponse.
        :rtype: list[ImUnreadV2]
        """
        return self._imunread

    @imunread.setter
    def imunread(self, imunread):
        """Sets the imunread of this ListUnreadNewInstantMessagesResponse.

        未读消息列表

        :param imunread: The imunread of this ListUnreadNewInstantMessagesResponse.
        :type: list[ImUnreadV2]
        """
        self._imunread = imunread

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUnreadNewInstantMessagesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkosm-3.0.63-py2.py3-none-any.whl: huaweicloudsdkosm/v2/model/list_unread_new_instant_messages_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListUnreadNewInstantMessagesResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'imunread': 'list[ImUnreadV2]'
    }

    attribute_map = {
        'imunread': 'imunread'
    }

    def __init__(self, imunread=None):
        """ListUnreadNewInstantMessagesResponse - a model defined in huaweicloud sdk"""
        
        super(ListUnreadNewInstantMessagesResponse, self).__init__()

        self._imunread = None
        self.discriminator = None

        if imunread is not None:
            self.imunread = imunread

    @property
    def imunread(self):
        """Gets the imunread of this ListUnreadNewInstantMessagesResponse.

        未读消息列表

        :return: The imunread of this ListUnreadNewInstantMessagesResponse.
        :rtype: list[ImUnreadV2]
        """
        return self._imunread

    @imunread.setter
    def imunread(self, imunread):
        """Sets the imunread of this ListUnreadNewInstantMessagesResponse.

        未读消息列表

        :param imunread: The imunread of this ListUnreadNewInstantMessagesResponse.
        :type: list[ImUnreadV2]
        """
        self._imunread = imunread

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListUnreadNewInstantMessagesResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
